@@ -25,7 +25,7 @@ function f=dft(f,N,dim);
 %@end deftypefn
 
 % Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.2
+% This file is part of LTFAT version 2.3.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -44,10 +44,10 @@ function f=dft(f,N,dim);
 %   TESTING: TEST_DFT
 %   REFERENCE: REF_DFT
 
-error(nargchk(1,3,nargin));
+complainif_argnonotinrange(nargin,1,3,mfilename);
 
 if nargin<3
-  dim=[];  
+  dim=[];
 end;
 
 if nargin<2
