@@ -10,7 +10,7 @@ function test_failed=test_gabmuleigs
 %@end deftypefn
 
 % Copyright (C) 2005-2016 Peter L. Soendergaard <peter@sonderport.dk>.
-% This file is part of LTFAT version 2.1.2
+% This file is part of LTFAT version 2.3.0
 %
 % This program is free software: you can redistribute it and/or modify
 % it under the terms of the GNU General Public License as published by
@@ -39,8 +39,12 @@ c=randn(M,N);
 
 g=gabtight(a,M,L);
 
-[V1,D1]=gabmuleigs(10,c,g,a,'iter');
-[V2,D2]=gabmuleigs(10,c,g,a,'full');
+% [V1,D1]=gabmuleigs(10,c,g,a,'iter');
+% [V2,D2]=gabmuleigs(10,c,g,a,'full');
+F = frame('dgt',g,a,M);
+c = framenative2coef(F,c);
+[V1,D1]=framemuleigs(F,F,c,10,'iter');
+[V2,D2]=framemuleigs(F,F,c,10,'full');
 
 res=norm(D1-D2);
 
